summaryrefslogtreecommitdiff
path: root/excelize.go
diff options
context:
space:
mode:
Diffstat (limited to 'excelize.go')
-rw-r--r--excelize.go4
1 files changed, 3 insertions, 1 deletions
diff --git a/excelize.go b/excelize.go
index 32f0451..32aa431 100644
--- a/excelize.go
+++ b/excelize.go
@@ -25,6 +25,7 @@ import (
type File struct {
checked map[string]bool
sheetMap map[string]string
+ CalcChain *xlsxCalcChain
ContentTypes *xlsxTypes
Path string
SharedStrings *xlsxSST
@@ -201,7 +202,8 @@ func (f *File) UpdateLinkedValue() {
// row: Index number of the row we're inserting/deleting before
// offset: Number of rows/column to insert/delete negative values indicate deletion
//
// TODO: adjustPageBreaks, adjustComments, adjustDataValidations, adjustProtectedCells
//
func (f *File) adjustHelper(sheet string, column, row, offset int) {
xlsx := f.workSheetReader(sheet)
@@ -201,7 +202,8 @@ func (f *File) UpdateLinkedValue() {
// offset: Number of rows/column to insert/delete negative values indicate deletion
//
-// TODO: adjustPageBreaks, adjustComments, adjustDataValidations, adjustProtectedCells
+// TODO: adjustCalcChain, adjustPageBreaks, adjustComments,
+// adjustDataValidations, adjustProtectedCells
//
func (f *File) adjustHelper(sheet string, column, row, offset int) {